# pijp

## Build status

[![CI](https://github.com/pijp-ci/pijp/actions/workflows/CI.yml/badge.svg)](https://github.com/pijp-ci/pijp/actions/workflows/CI.yml)

## Development environment

```
python3 -m venv .venv
source .venv/bin/activate
pip3 install -e ".[dev]"
```

Running the tests:

```
pytest -v
```